aboutsummaryrefslogtreecommitdiffstats
path: root/engine/pokemon/set_types.asm
diff options
context:
space:
mode:
Diffstat (limited to 'engine/pokemon/set_types.asm')
-rw-r--r--engine/pokemon/set_types.asm6
1 files changed, 3 insertions, 3 deletions
diff --git a/engine/pokemon/set_types.asm b/engine/pokemon/set_types.asm
index e9235f13..2cf8f14c 100644
--- a/engine/pokemon/set_types.asm
+++ b/engine/pokemon/set_types.asm
@@ -1,10 +1,10 @@
; updates the types of a party mon (pointed to in hl) to the ones of the mon specified in wd11e
SetPartyMonTypes:
call GetPredefRegisters
ld bc, wPartyMon1Type - wPartyMon1 ; $5
add hl, bc
- ld a, [wd11e]
- ld [wd0b5], a
+ ld a, [wPokedexNum]
+ ld [wCurSpecies], a
push hl
call GetMonHeader
pop hl
@@ -1,10 +1,10 @@
-; updates the types of a party mon (pointed to in hl) to the ones of the mon specified in wd11e
+; updates the types of a party mon (pointed to in hl) to the ones of the mon specified in [wPokedexNum]
SetPartyMonTypes:
call GetPredefRegisters